"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _StyleSheet = _interopRequireDefault(require("../../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../../style/css"));
var _Pressable = _interopRequireDefault(require("../../Pressable"));
var _Text = _interopRequireDefault(require("../../Text"));
var _Offcanvas = _interopRequireDefault(require("../../offcanvas/Offcanvas"));
var _useBackground = _interopRequireDefault(require("../../../hooks/useBackground"));
var _PickerNativeContext = _interopRequireDefault(require("./PickerNativeContext"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const styles = _StyleSheet.default.create({
  menu: (0, _css.default)`
    align-items: center;
  `
});

// Ref: https://reactnative.dev/docs/text-style-props
const textStyleKeys = ['color', 'fontFamily', 'fontSize', 'fontStyle', 'fontWeight', 'includeFontPaddingAndroid', 'fontVariant', 'letterSpacing', 'lineHeight', 'textAlign', 'textAlignVerticalAndroid', 'textDecorationColoriOS', 'textDecorationLine', 'textDecorationStyleiOS', 'textShadowColor', 'textShadowOffset', 'textShadowRadius', 'textTransform', 'writingDirection'];
const extractTextStyles = style => {
  const flattenedStyle = _reactNative.StyleSheet.flatten(style);
  const textStyles = {};
  Object.entries(flattenedStyle).forEach(([key, value]) => {
    if (textStyleKeys.includes(key)) {
      textStyles[key] = value;
    }
  });
  return textStyles;
};
const getText = ({
  children,
  selectedValue
}) => {
  const items = _react.default.Children.map(children, child => ({
    label: child.props.label,
    value: child.props.value
  }));
  const selectedItem = items?.find(item => item.value === selectedValue);
  return selectedItem?.label;
};
function DefaultMenuComponent({
  children,
  selectedValue,
  onValueChange: handleValueChange,
  onClose: handleClose
}) {
  const contextValue = (0, _react.useMemo)(() => ({
    selectedValue,
    handleValueChange
  }), [selectedValue, handleValueChange]);
  return /*#__PURE__*/_react.default.createElement(_Offcanvas.default, {
    placement: "bottom",
    visible: true,
    onToggle: handleClose
  }, /*#__PURE__*/_react.default.createElement(_Offcanvas.default.Body, {
    contentContainerStyle: styles.menu
  }, /*#__PURE__*/_react.default.createElement(_PickerNativeContext.default.Provider, {
    value: contextValue
  }, children)));
}
/* eslint-enable */

const PickerNative = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    selectedValue,
    onValueChange = () => {},
    onFocus = () => {},
    onBlur = () => {},
    placeholder,
    placeholderTextColor,
    disabled = false,
    MenuComponent = DefaultMenuComponent,
    style,
    ...elementProps
  } = props;
  const background = (0, _useBackground.default)(style);
  const [visible, setVisible] = (0, _react.useState)(false);
  const textStyle = extractTextStyles(background.style);
  const showPlaceholder = selectedValue === undefined || selectedValue === null;
  const handleValueChange = nextValue => {
    onValueChange(nextValue);
    setVisible(false);
  };
  const handleClose = () => {
    setVisible(false);
  };
  const handleFocus = event => {
    onFocus(event);
  };
  const handleBlur = event => {
    onBlur(event);
  };
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_Pressable.default, _extends({}, elementProps, {
    ref: ref,
    role: "combobox",
    onPress: () => {
      setVisible(true);
    },
    onFocus: event => {
      handleFocus(event);
    },
    onBlur: event => {
      handleBlur(event);
    },
    disabled: disabled,
    style: background.style
  }), background.element, /*#__PURE__*/_react.default.createElement(_Text.default, {
    numberOfLines: 1,
    style: [textStyle, showPlaceholder && {
      color: placeholderTextColor
    }]
  }, showPlaceholder ? placeholder || /*#__PURE__*/_react.default.createElement(_Text.default, null, "\xA0") : getText({
    children,
    selectedValue
  }))), visible && /*#__PURE__*/_react.default.createElement(MenuComponent, {
    selectedValue: selectedValue,
    onValueChange: handleValueChange,
    onClose: handleClose
  }, children));
});
var _default = exports.default = PickerNative;
//# sourceMappingURL=PickerNative.js.map