"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _View = _interopRequireDefault(require("../View"));
var _proxies = require("../../theme/proxies");
var _breakpoints = require("../../theme/breakpoints");
var _utils = require("../../utils");
var _NavbarText = _interopRequireDefault(require("./NavbarText"));
var _NavbarBrand = _interopRequireDefault(require("./NavbarBrand"));
var _NavbarCollapse = _interopRequireDefault(require("./NavbarCollapse"));
var _NavbarToggler = _interopRequireDefault(require("./NavbarToggler"));
var _NavbarContext = _interopRequireDefault(require("./NavbarContext"));
var _useNavbar = _interopRequireDefault(require("./useNavbar"));
var _useDismissNavbar = _interopRequireDefault(require("./useDismissNavbar"));
var _useToggleNavbar = _interopRequireDefault(require("./useToggleNavbar"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const styles = _StyleSheet.default.create({
  '.navbar': (0, _css.default)`
    position: relative;
    display: flex;
    flex-direction: row; // added for bootstrap-rn
    flex-wrap: wrap; // allow us to do the line break for collapsing content
    align-items: center;
    justify-content: space-between; // space out brand from logo
    padding-top: $navbar-padding-y;
    padding-right: $navbar-padding-x; // default: null
    padding-bottom: $navbar-padding-y;
    padding-left: $navbar-padding-x; // default: null
    // @include gradient-bg();
  `,
  ...(0, _utils.each)(_proxies.GRID_BREAKPOINTS, breakpoint => ({
    [`.navbar-expand${(0, _breakpoints.infix)((0, _breakpoints.next)(breakpoint))}`]: (0, _css.default)`
      @include media-breakpoint-up(${(0, _breakpoints.next)(breakpoint)}) {
        flex-wrap: nowrap;
        justify-content: flex-start;
      }
    `
  }))
});
const Navbar = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    variant = 'light',
    defaultExpanded = false,
    expanded,
    onToggle,
    expand,
    style,
    ...elementProps
  } = props;
  const navbar = (0, _useNavbar.default)(variant, defaultExpanded, expanded, onToggle, expand);
  const classes = (0, _utils.getStyles)(styles, ['.navbar', expand && `.navbar-expand${expand === true ? '' : `-${expand}`}`]);
  return /*#__PURE__*/_react.default.createElement(_View.default, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/_react.default.createElement(_NavbarContext.default.Provider, {
    value: navbar
  }, children));
});
Navbar.displayName = 'Navbar';
var _default = exports.default = Object.assign(Navbar, {
  Brand: _NavbarBrand.default,
  Text: _NavbarText.default,
  Collapse: _NavbarCollapse.default,
  Toggler: _NavbarToggler.default,
  useDismiss: _useDismissNavbar.default,
  useToggle: _useToggleNavbar.default
});
//# sourceMappingURL=Navbar.js.map