"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useBackground;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _reactNativeSvg = require("react-native-svg");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const styles = _reactNative.StyleSheet.create({
  container: {
    overflow: 'hidden'
  },
  object: {
    aspectRatio: 1
  }
});
const horizontalPositions = {
  left: (offset = 0) => ({
    alignItems: _reactNative.I18nManager.isRTL ? 'flex-end' : 'flex-start',
    paddingLeft: offset
  }),
  right: (offset = 0) => ({
    alignItems: _reactNative.I18nManager.isRTL ? 'flex-start' : 'flex-end',
    paddingRight: offset
  }),
  center: offset => {
    if (offset !== undefined) {
      return null;
    }
    return {
      alignItems: 'center'
    };
  },
  top: undefined,
  bottom: undefined
};
const verticalPositions = {
  top: (offset = 0) => ({
    justifyContent: 'flex-start',
    paddingTop: offset
  }),
  bottom: (offset = 0) => ({
    justifyContent: 'flex-end',
    paddingBottom: offset
  }),
  center: offset => {
    if (offset !== undefined) {
      return null;
    }
    return {
      justifyContent: 'center'
    };
  },
  left: undefined,
  right: undefined
};
const getXml = value => {
  const match = value.match(/^url\("data:image\/svg\+xml,(.*?)"\)$/);
  if (!match) {
    return null;
  }
  return decodeURIComponent(match[1]);
};
const transforms = {
  backgroundSize(value) {
    if (value === 'cover') {
      return {
        width: '100%'
        // TODO: Support cover for views with height > width.
        // height: '100%',
      };
    }
    if (value === 'contain') {
      return {
        width: '100%',
        height: '100%'
      };
    }
    const {
      width,
      height = width
    } = value;
    return {
      width,
      height
    };
  },
  backgroundPosition(value) {
    if (value === 'center') {
      return {
        alignItems: 'center',
        justifyContent: 'center'
      };
    }
    const horizontalPosition = horizontalPositions[value];
    if (horizontalPosition !== undefined) {
      return {
        ...horizontalPosition(),
        justifyContent: 'center'
      };
    }
    const verticalPosition = verticalPositions[value];
    if (verticalPosition) {
      return {
        alignItems: 'center',
        ...verticalPosition()
      };
    }
    return null;
  },
  backgroundPositionX(value) {
    const {
      position = 'left',
      offset
    } = typeof value === 'object' ? value : {
      position: value,
      offset: undefined
    };
    const horizontalPosition = horizontalPositions[position];
    if (!horizontalPosition) {
      return null;
    }
    return horizontalPosition(offset);
  },
  backgroundPositionY(value) {
    const {
      position = 'top',
      offset
    } = typeof value === 'object' ? value : {
      position: value,
      offset: undefined
    };
    const verticalPosition = horizontalPositions[position];
    if (!verticalPosition) {
      return null;
    }
    return verticalPosition(offset);
  }
};
function useBackground(style) {
  const flattenedStyle = _reactNative.StyleSheet.flatten(style);
  const background = {
    containerStyle: {},
    objectStyle: {},
    xml: null
  };
  Object.entries(flattenedStyle).forEach(([key, value]) => {
    if (!value) {
      return;
    }
    if (key === 'backgroundImage') {
      background.xml = getXml(value);
    } else if (key === 'backgroundSize') {
      Object.assign(background.objectStyle, transforms[key](value));
    } else if (key === 'backgroundPosition' || key === 'backgroundPositionX' || key === 'backgroundPositionY') {
      Object.assign(background.containerStyle, transforms[key](value));
    }
  });
  return {
    style: flattenedStyle,
    element: /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: [_reactNative.StyleSheet.absoluteFill, styles.container, background.containerStyle]
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: [styles.object, background.objectStyle]
    }, background.xml && /*#__PURE__*/_react.default.createElement(_reactNativeSvg.SvgXml, {
      xml: background.xml
    })))
  };
}
//# sourceMappingURL=useBackground.native.js.map