"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useInteractionState;
var _react = require("react");
var _focus = require("@react-native-aria/focus");
function useInteractionState({
  onFocus,
  onBlur,
  onHoverIn,
  onHoverOut,
  onPressIn,
  onPressOut,
  autoFocus
}) {
  const [active, setActive] = (0, _react.useState)(false);
  const [hover, setHovered] = (0, _react.useState)(false);

  // @ts-expect-error definition is on @react-aria/focus but not on @react-native-aria/focus
  const focusRingProps = (0, _focus.useFocusRing)({
    autoFocus
  });
  const {
    isFocused: focus,
    isFocusVisible: focusVisible,
    focusProps
  } = focusRingProps;
  const interactionProps = (0, _react.useMemo)(() => ({
    onHoverIn(event) {
      setHovered(true);
      if (onHoverIn) onHoverIn(event);
    },
    onHoverOut(event) {
      setHovered(false);
      if (onHoverOut) onHoverOut(event);
    },
    onFocus(event) {
      focusProps.onFocus(event);
      if (onFocus) onFocus(event);
    },
    onBlur(event) {
      focusProps.onBlur(event);
      if (onBlur) onBlur(event);
    },
    onPressIn(event) {
      setActive(true);
      if (onPressIn) onPressIn(event);
    },
    onPressOut(event) {
      setActive(false);
      if (onPressOut) onPressOut(event);
    }
  }), [onFocus, onBlur, onHoverIn, onHoverOut, onPressIn, onPressOut, focusProps]);
  const interaction = {
    hover,
    focus,
    focusVisible,
    active
  };
  return {
    interaction,
    interactionProps
  };
}
//# sourceMappingURL=useInteractionState.js.map