"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.concatRefs = concatRefs;
exports.each = each;
exports.getElementId = getElementId;
exports.getStyles = getStyles;
exports.makeArray = makeArray;
exports.makeProxy = makeProxy;
exports.normalize = normalize;
exports.optional = optional;
exports.transformPlacement = transformPlacement;
var _reactNative = require("react-native");
function each(source, apply) {
  return Object.entries(source).map(([key, value]) => {
    const resolve = typeof value === 'function' ? value : () => value;
    return apply(key, resolve);
  }).reduce((carry, item) => Object.assign(carry, item), {});
}
function normalize(value) {
  return value.reduce((carry, item) => Object.assign(carry, item), {});
}
function makeProxy(name, keys) {
  return keys.reduce((result, key) => ({
    ...result,
    [key]: t => t[name][key]
  }), {});
}
function makeArray(length, callback) {
  return Array.from({
    length
  }, (_, i) => callback(i));
}
function getStyles(styles, keys) {
  return keys.filter(key => !!key).map(key => styles[key]);
}
function concatRefs(...refs) {
  return element => {
    refs.forEach(ref => {
      if (typeof ref === 'function') {
        ref(element);
      } else if (ref) {
        // @ts-expect-error initially setting the ref is okay
        // eslint-disable-next-line no-param-reassign
        ref.current = element;
      }
    });
  };
}
function optional(condition, value) {
  return condition ? value : undefined;
}
function getElementId(identifier, name) {
  return `${identifier}${name ? `-${name}` : ''}`;
}
function transformPlacement(placement) {
  switch (placement) {
    case 'left':
      return _reactNative.I18nManager.isRTL ? 'end' : 'start';
    case 'right':
      return _reactNative.I18nManager.isRTL ? 'start' : 'end';
    default:
      return placement;
  }
}
//# sourceMappingURL=utils.js.map