import React, { useMemo, useRef } from 'react';
import { OverlayProvider } from '@react-native-aria/overlays';
import useViewport from './hooks/useViewport';
import useScrollbarEffects from './hooks/useScrollbarEffects';
import Context from './Context';
function Provider({
  children,
  utilities = {},
  modifiers = {},
  ssrViewport
}) {
  const viewport = useViewport(ssrViewport);
  const fixed = useMemo(() => [], []);
  const counter = useRef(0);
  const scrollbars = useScrollbarEffects(fixed);
  const context = useMemo(() => ({
    utilities,
    modifiers,
    scrollbars,
    fixed,
    getViewport() {
      return viewport;
    },
    addFixedElement(ref) {
      fixed.push(ref);
      return {
        remove() {
          const index = fixed.findIndex(item => item === ref);
          fixed.splice(index, 1);
        }
      };
    },
    generateKey(prefix) {
      counter.current += 1;
      return `ui-${prefix}-${counter.current}`;
    }
  }), [utilities, modifiers, scrollbars, fixed, viewport, fixed, counter]);
  return /*#__PURE__*/React.createElement(Context.Provider, {
    value: context
  }, /*#__PURE__*/React.createElement(OverlayProvider, null, children));
}
export default Provider;
//# sourceMappingURL=Provider.js.map