function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React from 'react';
import StyleSheet from '../style/StyleSheet';
import css from '../style/css';
import Text from './Text';
import { getStyles } from '../utils';
import useModifier from '../hooks/useModifier';
import useAction from '../hooks/useAction';
import useMedia from '../hooks/useMedia';
import useStyle from '../hooks/useStyle';
import useInteractionState from '../hooks/useInteractionState';
import { getRole } from './Pressable';

// We need to omit onPress here, because onPress can be null on UseActionableProps, but cannot be null on TextProps.

const styles = StyleSheet.create({
  link: css`
    color: $link-color;
    text-decoration-color: $link-color; // added for bootstrap-rn
    text-decoration-line: $link-decoration;

    &:hover {
      color: $link-hover-color;
      text-decoration-color: $link-hover-color; // added for bootstrap-rn
      text-decoration-line: $link-hover-decoration;
    }
  `
});
const Link = /*#__PURE__*/React.forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = useModifier('useActionable', props, ref);
  const [actionProps, actionRef] = useAction(modifierProps, modifierRef);
  const {
    children,
    // Filter hover handlers, because Text component does not have hover
    // handlers. Instead we use mouse enter/leave handlers.
    // @ts-expect-error see comment above
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    onHoverIn,
    // @ts-expect-error see comment above
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    onHoverOut,
    onMouseEnter: handleMouseEnter = () => {},
    onMouseLeave: handleMouseLeave = () => {},
    style,
    ...elementProps
  } = actionProps;
  const media = useMedia();
  const classes = getStyles(styles, ['link']);
  const resolveStyle = useStyle([classes, style]);
  const {
    interaction,
    interactionProps: {
      onHoverIn: handleMouseEnterInteraction,
      onHoverOut: handleMouseLeaveInteraction,
      ...interactionProps
    }
  } = useInteractionState(elementProps);
  return /*#__PURE__*/React.createElement(Text, _extends({}, elementProps, interactionProps, {
    // @ts-expect-error web only event
    onMouseEnter: event => {
      handleMouseEnter(event);
      handleMouseEnterInteraction(event);
    },
    onMouseLeave: event => {
      handleMouseLeave(event);
      handleMouseLeaveInteraction(event);
    },
    ref: actionRef,
    role: getRole(actionProps),
    accessible: true,
    style: resolveStyle({
      media,
      interaction
    })
  }), children);
});
Link.displayName = 'Link';
export default Link;
//# sourceMappingURL=Link.js.map