function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useContext, useMemo } from 'react';
import { Text, I18nManager, Pressable as BasePressable } from 'react-native';
import TextStyleContext from '../style/TextStyleContext';
import useModifier from '../hooks/useModifier';
import useAction from '../hooks/useAction';
import useMedia from '../hooks/useMedia';
import useStyle from '../hooks/useStyle';
import useInteractionState from '../hooks/useInteractionState';
import Caret from './Caret';
// One of the following should be set for aria support:
// 1) role
// 2) aria-label + aria-hint
// 3) accessibilityActions + onAccessibilityAction
export const getRole = props => {
  const {
    role,
    accessibilityActions
  } = props;
  if (role) {
    return role;
  }
  if (props['aria-label'] || accessibilityActions) {
    return undefined;
  }
  return 'button';
};
const applyCaret = (children, caret) => {
  if (!caret) {
    return children;
  }
  const options = caret === true ? {} : caret;
  const element = /*#__PURE__*/React.createElement(Caret, {
    color: options.color,
    direction: options.direction
  });
  const space = /*#__PURE__*/React.createElement(Text, null, " ");
  const isLeftCaret = options.direction === (I18nManager.isRTL ? 'end' : 'start');
  if (isLeftCaret) {
    return /*#__PURE__*/React.createElement(React.Fragment, null, element, space, children);
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, children, space, element);
};
const Pressable = /*#__PURE__*/React.forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = useModifier('useActionable', props, ref);
  const [actionProps, actionRef] = useAction(modifierProps, modifierRef);
  const {
    children,
    caret = false,
    active = false,
    style,
    activeStyle,
    textStyle,
    activeTextStyle,
    styleName,
    ...elementProps
  } = actionProps;
  const media = useMedia();
  const context = useContext(TextStyleContext);
  const resolveStyle = useStyle(style, styleName);
  const resolveActiveStyle = useStyle(active && activeStyle);
  const resolveTextStyle = useStyle([context && context.style, textStyle]);
  const resolveActiveTextStyle = useStyle(active && activeTextStyle);
  const {
    interaction,
    interactionProps
  } = useInteractionState(elementProps);
  const hasTextStyle = context && context.style || textStyle;
  const wrappedChildren = applyCaret(children, caret);
  const contextValue = useMemo(() => ({
    style: [resolveTextStyle({
      media,
      interaction
    }), resolveActiveTextStyle({
      media,
      interaction
    })],
    hasAncestor: context && context.hasTextAncestor
  }), [resolveTextStyle, resolveActiveTextStyle, media, interaction]);
  return /*#__PURE__*/React.createElement(BasePressable, _extends({}, elementProps, interactionProps, {
    ref: actionRef,
    role: getRole(actionProps),
    style: [resolveStyle({
      media,
      interaction
    }), resolveActiveStyle({
      media,
      interaction
    })]
  }), hasTextStyle ? /*#__PURE__*/React.createElement(TextStyleContext.Provider, {
    value: contextValue
  }, wrappedChildren) : wrappedChildren);
});
Pressable.displayName = 'Pressable';
export default Pressable;
//# sourceMappingURL=Pressable.js.map