function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useContext, useMemo } from 'react';
import { Text as BaseText } from 'react-native';
import StyleSheet from '../style/StyleSheet';
import css from '../style/css';
import useMedia from '../hooks/useMedia';
import TextStyleContext from '../style/TextStyleContext';
import { getStyles } from '../utils';
import useStyle from '../hooks/useStyle';
const styles = StyleSheet.create({
  text: css`
    font-family: $font-family-base;
    font-size: $font-size-base;
    font-weight: $font-weight-base;
    line-height: $font-size-base * $line-height-base;
  `,
  strong: css`
    font-weight: $font-weight-bolder;
  `,
  italic: css`
    font-style: italic;
  `,
  small: css`
    font-size: $small-font-size;
    line-height: $small-font-size * $line-height-base;
  `,
  mark: css`
    padding: $mark-padding;
    background-color: $mark-bg;
  `
});
const getStyleName = (styleName, color) => {
  if (!color) {
    return styleName;
  }
  return styleName ? `text-${color} ${styleName}` : `text-${color}`;
};
const Text = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    color,
    // will be deprecated soon
    bold = false,
    italic = false,
    mark = false,
    small = false,
    style,
    styleName,
    ...elementProps
  } = props;
  const media = useMedia();
  const context = useContext(TextStyleContext);
  const classes = getStyles(styles, [bold && 'strong', italic && 'italic', small && 'small', mark && 'mark']);
  const resolveStyle = useStyle([(!context || !context.hasTextAncestor) && styles.text, context && context.style, classes, style], getStyleName(styleName, color));
  const contextValue = useMemo(() => ({
    style: null,
    hasTextAncestor: true
  }), []);
  const element = /*#__PURE__*/React.createElement(BaseText, _extends({}, elementProps, {
    ref: ref,
    style: resolveStyle({
      media
    })
  }));
  if (context && context.hasTextAncestor && !context.style) {
    return element;
  }
  return /*#__PURE__*/React.createElement(TextStyleContext.Provider, {
    value: contextValue
  }, element);
});
Text.displayName = 'Text';
export default Text;
//# sourceMappingURL=Text.js.map