function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useState, useMemo } from 'react';
import { StyleSheet as StyleUtils } from 'react-native';
import StyleSheet from '../../../style/StyleSheet';
import css from '../../../style/css';
import Pressable from '../../Pressable';
import Text from '../../Text';
import Offcanvas from '../../offcanvas/Offcanvas';
import useBackground from '../../../hooks/useBackground';
import PickerNativeContext from './PickerNativeContext';
const styles = StyleSheet.create({
  menu: css`
    align-items: center;
  `
});

// Ref: https://reactnative.dev/docs/text-style-props
const textStyleKeys = ['color', 'fontFamily', 'fontSize', 'fontStyle', 'fontWeight', 'includeFontPaddingAndroid', 'fontVariant', 'letterSpacing', 'lineHeight', 'textAlign', 'textAlignVerticalAndroid', 'textDecorationColoriOS', 'textDecorationLine', 'textDecorationStyleiOS', 'textShadowColor', 'textShadowOffset', 'textShadowRadius', 'textTransform', 'writingDirection'];
const extractTextStyles = style => {
  const flattenedStyle = StyleUtils.flatten(style);
  const textStyles = {};
  Object.entries(flattenedStyle).forEach(([key, value]) => {
    if (textStyleKeys.includes(key)) {
      textStyles[key] = value;
    }
  });
  return textStyles;
};
const getText = ({
  children,
  selectedValue
}) => {
  const items = React.Children.map(children, child => ({
    label: child.props.label,
    value: child.props.value
  }));
  const selectedItem = items?.find(item => item.value === selectedValue);
  return selectedItem?.label;
};
function DefaultMenuComponent({
  children,
  selectedValue,
  onValueChange: handleValueChange,
  onClose: handleClose
}) {
  const contextValue = useMemo(() => ({
    selectedValue,
    handleValueChange
  }), [selectedValue, handleValueChange]);
  return /*#__PURE__*/React.createElement(Offcanvas, {
    placement: "bottom",
    visible: true,
    onToggle: handleClose
  }, /*#__PURE__*/React.createElement(Offcanvas.Body, {
    contentContainerStyle: styles.menu
  }, /*#__PURE__*/React.createElement(PickerNativeContext.Provider, {
    value: contextValue
  }, children)));
}
/* eslint-enable */

const PickerNative = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    children,
    selectedValue,
    onValueChange = () => {},
    onFocus = () => {},
    onBlur = () => {},
    placeholder,
    placeholderTextColor,
    disabled = false,
    MenuComponent = DefaultMenuComponent,
    style,
    ...elementProps
  } = props;
  const background = useBackground(style);
  const [visible, setVisible] = useState(false);
  const textStyle = extractTextStyles(background.style);
  const showPlaceholder = selectedValue === undefined || selectedValue === null;
  const handleValueChange = nextValue => {
    onValueChange(nextValue);
    setVisible(false);
  };
  const handleClose = () => {
    setVisible(false);
  };
  const handleFocus = event => {
    onFocus(event);
  };
  const handleBlur = event => {
    onBlur(event);
  };
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Pressable, _extends({}, elementProps, {
    ref: ref,
    role: "combobox",
    onPress: () => {
      setVisible(true);
    },
    onFocus: event => {
      handleFocus(event);
    },
    onBlur: event => {
      handleBlur(event);
    },
    disabled: disabled,
    style: background.style
  }), background.element, /*#__PURE__*/React.createElement(Text, {
    numberOfLines: 1,
    style: [textStyle, showPlaceholder && {
      color: placeholderTextColor
    }]
  }, showPlaceholder ? placeholder || /*#__PURE__*/React.createElement(Text, null, "\xA0") : getText({
    children,
    selectedValue
  }))), visible && /*#__PURE__*/React.createElement(MenuComponent, {
    selectedValue: selectedValue,
    onValueChange: handleValueChange,
    onClose: handleClose
  }, children));
});
export default PickerNative;
//# sourceMappingURL=PickerNative.js.map