import { useState, useMemo } from 'react';
import { useFocusRing } from '@react-native-aria/focus';
export default function useInteractionState({
  onFocus,
  onBlur,
  onHoverIn,
  onHoverOut,
  onPressIn,
  onPressOut,
  autoFocus
}) {
  const [active, setActive] = useState(false);
  const [hover, setHovered] = useState(false);

  // @ts-expect-error definition is on @react-aria/focus but not on @react-native-aria/focus
  const focusRingProps = useFocusRing({
    autoFocus
  });
  const {
    isFocused: focus,
    isFocusVisible: focusVisible,
    focusProps
  } = focusRingProps;
  const interactionProps = useMemo(() => ({
    onHoverIn(event) {
      setHovered(true);
      if (onHoverIn) onHoverIn(event);
    },
    onHoverOut(event) {
      setHovered(false);
      if (onHoverOut) onHoverOut(event);
    },
    onFocus(event) {
      focusProps.onFocus(event);
      if (onFocus) onFocus(event);
    },
    onBlur(event) {
      focusProps.onBlur(event);
      if (onBlur) onBlur(event);
    },
    onPressIn(event) {
      setActive(true);
      if (onPressIn) onPressIn(event);
    },
    onPressOut(event) {
      setActive(false);
      if (onPressOut) onPressOut(event);
    }
  }), [onFocus, onBlur, onHoverIn, onHoverOut, onPressIn, onPressOut, focusProps]);
  const interaction = {
    hover,
    focus,
    focusVisible,
    active
  };
  return {
    interaction,
    interactionProps
  };
}
//# sourceMappingURL=useInteractionState.js.map